/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgFilterCustomAction.idl
 */

#ifndef __gen_nsIMsgFilterCustomAction_h__
#define __gen_nsIMsgFilterCustomAction_h__


#ifndef __gen_nsMsgFilterCore_h__
#include "nsMsgFilterCore.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIMsgFilterCustomAction */
#define NS_IMSGFILTERCUSTOMACTION_IID_STR "4699c41e-3671-436e-b6ae-4fd8106747e4"

#define NS_IMSGFILTERCUSTOMACTION_IID \
  {0x4699c41e, 0x3671, 0x436e, \
    { 0xb6, 0xae, 0x4f, 0xd8, 0x10, 0x67, 0x47, 0xe4 }}

/**
 * describes a custom action added to a message filter
 */
class NS_NO_VTABLE NS_SCRIPTABLE nsIMsgFilterCustomAction : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGFILTERCUSTOMACTION_IID)

  /* readonly attribute ACString id; */
  NS_SCRIPTABLE NS_IMETHOD GetId(nsACString & aId) = 0;

  /* readonly attribute AString name; */
  NS_SCRIPTABLE NS_IMETHOD GetName(nsAString & aName) = 0;

  /**
   * Is this custom action valid for a particular filter type? 
   *
   * @param type    the filter type
   * @param scope   the search scope
   *
   * @return        true if valid
   */
  /* boolean isValidForType (in nsMsgFilterTypeType type, in nsMsgSearchScopeValue scope); */
  NS_SCRIPTABLE NS_IMETHOD IsValidForType(nsMsgFilterTypeType type, nsMsgSearchScopeValue scope, PRBool *_retval NS_OUTPARAM) = 0;

  /**
   * After the user inputs a particular action value for the action, determine
   * if that value is valid.
   *
   * @param actionValue          The value entered.
   * @param actionFolder         Folder in the filter list
   * @param filterType           Filter Type (Manual, OfflineMail, etc.)
   *
   * @return errorMessage        A localized message to display if invalid
   *                             Set to null if the actionValue is valid
   */
  /* AUTF8String validateActionValue (in AUTF8String actionValue, in nsIMsgFolder actionFolder, in nsMsgFilterTypeType filterType); */
  NS_SCRIPTABLE NS_IMETHOD ValidateActionValue(const nsACString & actionValue, nsIMsgFolder *actionFolder, nsMsgFilterTypeType filterType, nsACString & _retval NS_OUTPARAM) = 0;

  /* attribute boolean allowDuplicates; */
  NS_SCRIPTABLE NS_IMETHOD GetAllowDuplicates(PRBool *aAllowDuplicates) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetAllowDuplicates(PRBool aAllowDuplicates) = 0;

  /**
   * Apply the custom action to an array of messages
   *
   * @param msgHdrs      array of nsIMsgDBHdr objects of messages
   * @param actionValue  user-set value to use in the action
   * @param copyListener calling method (filterType Manual only)
   * @param filterType   type of filter being applied
   * @param msgWindow    message window
   */
  /* void apply (in nsIArray msgHdrs, in AUTF8String actionValue, in nsIMsgCopyServiceListener copyListener, in nsMsgFilterTypeType filterType, in nsIMsgWindow msgWindow); */
  NS_SCRIPTABLE NS_IMETHOD Apply(nsIArray *msgHdrs, const nsACString & actionValue, nsIMsgCopyServiceListener *copyListener, nsMsgFilterTypeType filterType, nsIMsgWindow *msgWindow) = 0;

  /* readonly attribute boolean isAsync; */
  NS_SCRIPTABLE NS_IMETHOD GetIsAsync(PRBool *aIsAsync) = 0;

  /* readonly attribute boolean needsBody; */
  NS_SCRIPTABLE NS_IMETHOD GetNeedsBody(PRBool *aNeedsBody) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgFilterCustomAction, NS_IMSGFILTERCUSTOMACTION_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGFILTERCUSTOMACTION \
  NS_SCRIPTABLE NS_IMETHOD GetId(nsACString & aId); \
  NS_SCRIPTABLE NS_IMETHOD GetName(nsAString & aName); \
  NS_SCRIPTABLE NS_IMETHOD IsValidForType(nsMsgFilterTypeType type, nsMsgSearchScopeValue scope, PRBool *_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD ValidateActionValue(const nsACString & actionValue, nsIMsgFolder *actionFolder, nsMsgFilterTypeType filterType, nsACString & _retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD GetAllowDuplicates(PRBool *aAllowDuplicates); \
  NS_SCRIPTABLE NS_IMETHOD SetAllowDuplicates(PRBool aAllowDuplicates); \
  NS_SCRIPTABLE NS_IMETHOD Apply(nsIArray *msgHdrs, const nsACString & actionValue, nsIMsgCopyServiceListener *copyListener, nsMsgFilterTypeType filterType, nsIMsgWindow *msgWindow); \
  NS_SCRIPTABLE NS_IMETHOD GetIsAsync(PRBool *aIsAsync); \
  NS_SCRIPTABLE NS_IMETHOD GetNeedsBody(PRBool *aNeedsBody); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGFILTERCUSTOMACTION(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetId(nsACString & aId) { return _to GetId(aId); } \
  NS_SCRIPTABLE NS_IMETHOD GetName(nsAString & aName) { return _to GetName(aName); } \
  NS_SCRIPTABLE NS_IMETHOD IsValidForType(nsMsgFilterTypeType type, nsMsgSearchScopeValue scope, PRBool *_retval NS_OUTPARAM) { return _to IsValidForType(type, scope, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD ValidateActionValue(const nsACString & actionValue, nsIMsgFolder *actionFolder, nsMsgFilterTypeType filterType, nsACString & _retval NS_OUTPARAM) { return _to ValidateActionValue(actionValue, actionFolder, filterType, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD GetAllowDuplicates(PRBool *aAllowDuplicates) { return _to GetAllowDuplicates(aAllowDuplicates); } \
  NS_SCRIPTABLE NS_IMETHOD SetAllowDuplicates(PRBool aAllowDuplicates) { return _to SetAllowDuplicates(aAllowDuplicates); } \
  NS_SCRIPTABLE NS_IMETHOD Apply(nsIArray *msgHdrs, const nsACString & actionValue, nsIMsgCopyServiceListener *copyListener, nsMsgFilterTypeType filterType, nsIMsgWindow *msgWindow) { return _to Apply(msgHdrs, actionValue, copyListener, filterType, msgWindow); } \
  NS_SCRIPTABLE NS_IMETHOD GetIsAsync(PRBool *aIsAsync) { return _to GetIsAsync(aIsAsync); } \
  NS_SCRIPTABLE NS_IMETHOD GetNeedsBody(PRBool *aNeedsBody) { return _to GetNeedsBody(aNeedsBody); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGFILTERCUSTOMACTION(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetId(nsACString & aId) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetId(aId); } \
  NS_SCRIPTABLE NS_IMETHOD GetName(nsAString & aName) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetName(aName); } \
  NS_SCRIPTABLE NS_IMETHOD IsValidForType(nsMsgFilterTypeType type, nsMsgSearchScopeValue scope, PRBool *_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->IsValidForType(type, scope, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD ValidateActionValue(const nsACString & actionValue, nsIMsgFolder *actionFolder, nsMsgFilterTypeType filterType, nsACString & _retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->ValidateActionValue(actionValue, actionFolder, filterType, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD GetAllowDuplicates(PRBool *aAllowDuplicates) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAllowDuplicates(aAllowDuplicates); } \
  NS_SCRIPTABLE NS_IMETHOD SetAllowDuplicates(PRBool aAllowDuplicates) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetAllowDuplicates(aAllowDuplicates); } \
  NS_SCRIPTABLE NS_IMETHOD Apply(nsIArray *msgHdrs, const nsACString & actionValue, nsIMsgCopyServiceListener *copyListener, nsMsgFilterTypeType filterType, nsIMsgWindow *msgWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->Apply(msgHdrs, actionValue, copyListener, filterType, msgWindow); } \
  NS_SCRIPTABLE NS_IMETHOD GetIsAsync(PRBool *aIsAsync) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIsAsync(aIsAsync); } \
  NS_SCRIPTABLE NS_IMETHOD GetNeedsBody(PRBool *aNeedsBody) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNeedsBody(aNeedsBody); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgFilterCustomAction : public nsIMsgFilterCustomAction
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGFILTERCUSTOMACTION

  nsMsgFilterCustomAction();

private:
  ~nsMsgFilterCustomAction();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgFilterCustomAction, nsIMsgFilterCustomAction)

nsMsgFilterCustomAction::nsMsgFilterCustomAction()
{
  /* member initializers and constructor code */
}

nsMsgFilterCustomAction::~nsMsgFilterCustomAction()
{
  /* destructor code */
}

/* readonly attribute ACString id; */
NS_IMETHODIMP nsMsgFilterCustomAction::GetId(nsACString & aId)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute AString name; */
NS_IMETHODIMP nsMsgFilterCustomAction::GetName(nsAString & aName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean isValidForType (in nsMsgFilterTypeType type, in nsMsgSearchScopeValue scope); */
NS_IMETHODIMP nsMsgFilterCustomAction::IsValidForType(nsMsgFilterTypeType type, nsMsgSearchScopeValue scope, PRBool *_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* AUTF8String validateActionValue (in AUTF8String actionValue, in nsIMsgFolder actionFolder, in nsMsgFilterTypeType filterType); */
NS_IMETHODIMP nsMsgFilterCustomAction::ValidateActionValue(const nsACString & actionValue, nsIMsgFolder *actionFolder, nsMsgFilterTypeType filterType, nsACString & _retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean allowDuplicates; */
NS_IMETHODIMP nsMsgFilterCustomAction::GetAllowDuplicates(PRBool *aAllowDuplicates)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgFilterCustomAction::SetAllowDuplicates(PRBool aAllowDuplicates)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void apply (in nsIArray msgHdrs, in AUTF8String actionValue, in nsIMsgCopyServiceListener copyListener, in nsMsgFilterTypeType filterType, in nsIMsgWindow msgWindow); */
NS_IMETHODIMP nsMsgFilterCustomAction::Apply(nsIArray *msgHdrs, const nsACString & actionValue, nsIMsgCopyServiceListener *copyListener, nsMsgFilterTypeType filterType, nsIMsgWindow *msgWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean isAsync; */
NS_IMETHODIMP nsMsgFilterCustomAction::GetIsAsync(PRBool *aIsAsync)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean needsBody; */
NS_IMETHODIMP nsMsgFilterCustomAction::GetNeedsBody(PRBool *aNeedsBody)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgFilterCustomAction_h__ */
